package com.docus.server.collect.user.http;

import com.docus.server.collect.ICollector;
import com.docus.server.collect.IHttpCollector;
import com.docus.server.collect.web.job.AbstractCollectJob;
import com.docus.server.sys.common.pojo.dto.UserDTO;
import com.xxl.job.core.handler.annotation.XxlJob;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * 主动http请求用户数据job
 *
 * @see AbstractCollectJob
 * @see com.docus.server.collect.IJob
 * @see IHttpCollector
 */
@Component
public class UserHttpCollectJob extends AbstractCollectJob<UserDTO> {
    @Resource(name = "httpUserCollectorImpl")
    private ICollector collector;

    /**
     * xxl jobhandler 手工执行
     */
    @XxlJob("startAllUserHttpCollect")
    public void startAllUserHttpCollect() {
        super.startCollectAll(getJobParam());
    }

    /**
     * xxl jobhandler 配置定时启动，如果未完成任务跳过。
     */
    @XxlJob("startIncUserHttpCollect")
    public void startIncUserHttpCollect() {
        super.startCollectIncrement(getJobParam());
    }

    @Override
    public void batchInsertOrUpdate(List<UserDTO> t) {
        userService.batchInsertOrUpdatePowerUser(t);
    }

    @SuppressWarnings("unchecked")
    @Override
    public List<UserDTO> execute(Date startDate, Date endDate, int pageNum, int pageSize) {
        //需要根据不同医院去解析不同的内容。使用接口实现的方式。
        return collector.list(startDate, endDate, pageNum, pageSize);
    }
}
