package com.docus.server.collect.web.job;

import com.docus.core.util.Func;
import com.docus.server.collect.IJob;
import com.docus.server.collect.web.domain.TaskConfig;
import com.docus.server.collect.web.enums.StateEnum;
import com.docus.server.collect.web.service.ITaskConfigService;
import com.docus.server.collect.web.utils.PeriodTime;
import com.docus.server.record.service.ITBasicService;
import com.docus.server.sys.service.IPowerDeptService;
import com.docus.server.sys.service.IPowerUserService;
import com.xxl.job.core.context.XxlJobHelper;
import org.springframework.beans.factory.annotation.Autowired;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

public abstract class AbstractCollectJob<T> implements IJob<T> {
    @Resource
    protected IPowerUserService userService;
    @Resource
    protected IPowerDeptService deptService;
    @Autowired
    protected ITBasicService basicService;
    @Resource
    protected ITaskConfigService taskConfigService;

    @Override
    public void startCollectAll(String taskConfigId) {
        TaskConfig taskConfig = getTaskConfig(taskConfigId);

        try {
            List<PeriodTime> periodTimes = taskConfig.getAllPeriodTimes();
            for (PeriodTime periodTime : periodTimes) {
                get(periodTime, taskConfig);
                taskConfigService.updateAllPointerDate(taskConfigId, periodTime.getPeriodEndDate());
            }
        } catch (Exception ex) {
            updateTaskState(ex, taskConfig);
        }
    }


    @Override
    public void startCollectIncrement(String taskConfigId) {
        TaskConfig taskConfig = taskConfigService.getTaskConfig(taskConfigId);
        try {

            List<PeriodTime> periodTimes = taskConfig.getIncPeriodTimes();
            periodTimes.forEach(periodTime -> {
                get(periodTime, taskConfig);
                taskConfigService.updateIncPointerDate(taskConfigId, periodTime.getPeriodEndDate());
            });

        } catch (Exception ex) {
            updateTaskState(ex, taskConfig);
        }
    }

    @Override
    public void get(PeriodTime periodTime, TaskConfig taskConfig) {
        //考虑到性能，应该把起始时间和结束时间进行切割拆分到每天。按段查询。
        List<T> t;
        int pageNum = 1;
        for (; true; pageNum++) {
            t = this.execute(
                periodTime.getPeriodStartDate(),
                periodTime.getPeriodEndDate(),
                pageNum,
                taskConfig.getPageSize()
            );
            if (Func.isEmpty(t)) {
                break;
            }

            this.batchInsertOrUpdate(t);
        }
    }

    private void updateTaskState(Exception ex, TaskConfig taskConfig) {
        taskConfig.setState(StateEnum.FAIL);
        String message = ex.getMessage();
        taskConfig.setErrorMsg(message.length() > 500 ? message.substring(0, 500) : message);
        taskConfigService.updateByTaskId(taskConfig);
    }

    private TaskConfig getTaskConfig(String taskConfigId) {
        return taskConfigService.getTaskConfig(taskConfigId);
    }

    protected String getJobParam() {
        return XxlJobHelper.getJobParam();
    }

    public abstract void batchInsertOrUpdate(List<T> t);

    public abstract List<T> execute(Date startDate, Date endDate, int pageNum, int pageSize);
}
